==> 0.2.10.tar.gz: lib/big.dart <==
library big;
import 'dart:mirrors'; 
import 'dart:js';

//Library Scoped methods and attributes
String typeof(var obj){
  return((obj is BigNumber)?'BigNumber':reflect(obj).type.reflectedType.toString());
  }//end Dart version of typeof

class BigNumber{
  //Static methods and attributes
  static Exception noBigNumberJS=new Exception('Big:BigNumber:: Your Dart project cannot access bignumber.js!,\n'+
      'Add the HTML tag <script src="bignumber.js"></script> to your <<project>>.html file!\n');
  static Exception noAccessToConfig=new Exception("Big::BigNumber.config(): Your version of bignumber.js has not been modified for the Dart Language!,\n"+
      "Add the code line P['config']=BigNumber['config']; after the config function in bignumber.js!\n"+
      "This will enable calls to BigNumber.config() from Dart.");
  static JsObject configObj=null;
  static Map config([Map<String, dynamic> arguments=null]){
    JsObject configCurrent=null;
    Map m=new Map();
    arguments=(arguments==null)?new Map():arguments;
    JsObject args = new JsObject(context['Object'],['0']);
    try{
      if(configObj==null)configObj=new JsObject(context['BigNumber'],['0']);
    }catch(ee){
      throw noBigNumberJS;//Then halt!
    }//end try
    try{
      arguments.forEach((param, value){
        if(param=='EXPONENTIAL_AT'||param=='RANGE'){
          if(value is! num){
            value=new JsObject(context['Array'],[(value[0] is num)?value[0].floor():value[0], (value[1] is num)?value[1].floor():value[1]]);
          }//end if
        }//end if
        args[param]=value;
      });//end foreach
      configCurrent=configObj.callMethod('config',[args]);
    }on NoSuchMethodError catch(ee){
      print(noAccessToConfig.toString());
      m['No_Access_To_Config!']=noAccessToConfig.toString();
      return (m);
    }catch(ee){
      print(ee.toString());
      m['Config Error!']=ee.toString();
      return (m);
    }//end try
    m['DECIMAL_PLACES']=configCurrent['DECIMAL_PLACES'];
    m['ROUNDING_MODE']=configCurrent['ROUNDING_MODE'];
    m['EXPONENTIAL_AT']=configCurrent['EXPONENTIAL_AT'];
    m['RANGE']=configCurrent['RANGE'];
    m['ERRORS']=configCurrent['ERRORS'];
    return (m);
  }//end config
  static String test(){
    String str='';
    print('Testing BigNumber ...............START..................');
    BigNumber bigTest=null;
    BigNumber bigTestFromBigNumber;
    Map m = config({'DECIMAL_PLACES' : 20});//test that call to config is enabled!
    str+='config() test:\n'+m.toString();
  try{
    bigTest = new BigNumber('12345678901234567890.12345678901234567890');
    str+=r"BigNumber bigTest = new BigNumber('12345678901234567890.12345678901234567890');";
    str+='\nabs(): '+bigTest.abs().toS();
    str+='\nceil(): '+bigTest.ceil().toS();
    str+='\ncmp(989897): '+bigTest.cmp(989897).toString();
    str+='\ndiv(self): '+bigTest.div(bigTest).toS();
    str+='\ndiv(54444): '+bigTest.div(54444).toS();
    str+='\nfloor(): '+bigTest.floor().toS();
    str+='\nminus(self): '+bigTest.minus(bigTest).toS();
    str+='\nneg(): '+bigTest.neg().toS();
    str+='\nplus(self): '+bigTest.plus(bigTest).toS();
    str+='\npow(2): '+bigTest.pow(2).toS();
    str+='\nround(): '+bigTest.round(4).toS();
    str+='\n(64*64).sqrt(): '+new BigNumber(64*64).sqrt().toS();
    str+='\ntimes(self): '+bigTest.times(bigTest).toS();
    str+='\ntoExponential(): '+bigTest.toExponential();
    str+='\ntoFixed(10): '+bigTest.toFixed(10);
    str+='\nequals(454.55)? ${bigTest.equals(454.55)}';
    str+='\ngreaterThan(454.55)? ${bigTest.greaterThan(454.55)}';
    str+='\ngreaterThanOrEqualTo(454.55)? ${bigTest.greaterThanOrEqualTo(454.55)}';
    str+='\nlessThan(454.55)? ${bigTest.lessThan(454.55)}';
    str+='\nlessThanOrEqualTo(454.55)? ${bigTest.lessThanOrEqualTo(454.55)}';
    List toFraction = bigTest.toFraction();
    str+='\ntoFraction(): ';
    toFraction.forEach((E){str+='\n\t'+E.toString();});
    str+='\ntoPrecision(60): '+bigTest.toPrecision(60);
    str+='\ntoString(base:16): '+bigTest.toString(16);
    bigTestFromBigNumber=new BigNumber(bigTest);
    str+='\nTest constructor: b=new BigNumber(BigNumber): '+bigTestFromBigNumber.toString();
  }catch(ee){
    str+='\n'+ee.toString();
  }finally{}
    print(str);
    print('Testing BigNumber ...............END....................');
    return(str);
  }//end test
  /********************************END TEST*****************************************************/
  //Instance methods and attributes
  String sourceType='unknown';
  JsObject JsObject_BigNumber = null;
  //Main Constructor
  BigNumber(var value, [int base=null]) {
    sourceType = typeof(value);
    try{JsObject_BigNumber=new JsObject(context['BigNumber'], [(value is BigNumber)?value.JsObject_BigNumber:value, base]);}catch(ee){throw noBigNumberJS;}
  }//end constructor
  // PROTOTYPE/INSTANCE METHODS
  BigNumber abs(){return absoluteValue();}
  BigNumber absoluteValue(){return(new BigNumber(JsObject_BigNumber.callMethod('absoluteValue')));}
  BigNumber ceil(){return(new BigNumber(JsObject_BigNumber.callMethod('ceil')));}
  int cmp(var y, [int base=null]){return(comparedTo(y, base));}
  int comparedTo(var y, [int base=null]) {return(JsObject_BigNumber.callMethod('comparedTo',[(y is BigNumber)?y.JsObject_BigNumber:y, base]));}
  BigNumber div(var y, [int base=null]){return(dividedBy(y, base));}
  BigNumber dividedBy(var y, [int base=null]){
    return(new BigNumber(JsObject_BigNumber.callMethod('dividedBy',[(y is BigNumber)?y.JsObject_BigNumber:y, base])));
  }//end method
  bool eq(var n, [int base=null]){return(equals(n, base));}
  bool equals(var n, [int base=null]){return(JsObject_BigNumber.callMethod('equals',[(n is BigNumber)?n.JsObject_BigNumber:n, base]));}
  bool gt(var n, [int base=null]){return(greaterThan(n, base));}
  bool greaterThan(var n, [int base=null]){return(JsObject_BigNumber.callMethod('greaterThan',[(n is BigNumber)?n.JsObject_BigNumber:n, base]));}
  bool gte(var n, [int base=null]){return(greaterThanOrEqualTo(n, base));}
  bool greaterThanOrEqualTo(
       var n, [int base=null]){return(JsObject_BigNumber.callMethod('greaterThanOrEqualTo',[(n is BigNumber)?n.JsObject_BigNumber:n, base]));}
  bool isF(){return(isFinite());}
  bool isFinite(){return(JsObject_BigNumber.callMethod('isFinite'));}
  bool isNaN(){return(JsObject_BigNumber.callMethod('isNan'));}
  bool isNeg(){return(isNegative());} 
  bool isNegative(){return(JsObject_BigNumber.callMethod('isNegative'));}
  bool isZ(){return(isZero());}
  bool isZero(){return(JsObject_BigNumber.callMethod('isZero'));}
  bool lt(var n, [int base=null]){return(lessThan(n, base));}
  bool lessThan(var n, [int base=null]){return(JsObject_BigNumber.callMethod('lessThan',[(n is BigNumber)?n.JsObject_BigNumber:n, base]));}
  bool lte(var n, [int base=null]){return(lessThanOrEqualTo(n, base));}
  bool lessThanOrEqualTo(
       var n, [int base=null]) {return(JsObject_BigNumber.callMethod('lessThanOrEqualTo',[(n is BigNumber)?n.JsObject_BigNumber:n, base]));}
  BigNumber floor(){return(new BigNumber(JsObject_BigNumber.callMethod('floor')));}
  BigNumber minus(var y, [int base=null]) {return(new BigNumber(JsObject_BigNumber.callMethod('minus',[(y is BigNumber)?y.JsObject_BigNumber:y, base])));}
  BigNumber mod(var y, [int base=null]){return(modulo(y, base));}
  BigNumber modulo(var y, [int base=null]) {return(new BigNumber(JsObject_BigNumber.callMethod('modulo',[(y is BigNumber)?y.JsObject_BigNumber:y, base])));}
  BigNumber neg() {return(negated());}
  BigNumber negated(){return(new BigNumber(JsObject_BigNumber.callMethod('negated')));}
  BigNumber plus(var y, [int base=null]){return(new BigNumber(JsObject_BigNumber.callMethod('plus',[(y is BigNumber)?y.JsObject_BigNumber:y, base])));}
  BigNumber pow(int e){return(toPower(e));}
  BigNumber toPower(int e) {return(new BigNumber(JsObject_BigNumber.callMethod('toPower',[e])));}
  BigNumber round(decimalPlaces, [int roundingMode=null]){return(new BigNumber(JsObject_BigNumber.callMethod('round',[decimalPlaces,roundingMode])));}
  BigNumber sqrt(){return(squareRoot());}
  BigNumber squareRoot(){return(new BigNumber(JsObject_BigNumber.callMethod('squareRoot')));}
  BigNumber times(var y, [int base=null]){return(new BigNumber(JsObject_BigNumber.callMethod('times',[(y is BigNumber)?y.JsObject_BigNumber:y, base])));}
  String toE([int decimal_places=null]){return(toExponential(decimal_places));}
  String toExponential([int decimal_places=null]){return(JsObject_BigNumber.callMethod('toExponential',[decimal_places]));}
  String toF([int decimal_places=null] ){return(toFixed(decimal_places));}
  String toFixed([int decimal_places=null]){return(JsObject_BigNumber.callMethod('toFixed',[decimal_places]));}
  List toFr([var maxDenominator=null]){return(toFraction(maxDenominator));}
  List toFraction([var maxDenominator=null]){return(JsObject_BigNumber.callMethod('toFraction',[maxDenominator]));}
  String toP([int significant_figures=null]){return(toPrecision(significant_figures));}
  String toPrecision([int significant_figures=null]){return(JsObject_BigNumber.callMethod('toPrecision',[significant_figures]));}
  String toS([int base=null]){return(this.toString(base));}
  String toString([int base=null]){return(JsObject_BigNumber.callMethod('toString',[base]));}
  String valueOf(){return(JsObject_BigNumber.callMethod('toString'));}

  String toStringInstance(){//JsObject_BigNumber
    String str='';
    str+='BigNumber::toStringInstance: type: '+sourceType+', Sign: '+JsObject_BigNumber['s'].toString()+', Exponent: '
        +JsObject_BigNumber['e'].toString()+',\n component:[';
    JsObject_BigNumber['c'].forEach((E){str+=' '+E.toString();});
    str+=' ]';
    str+=',\n String: toString['+toString()+']';
    str+=',\n toFixed['+toF()+']';
    str+='\n abs['+abs().toS()+']';
    return(str);
  }//end method
}//end class

==> 0.2.11.tar.gz: lib/big.dart <==
library big;
import 'dart:mirrors'; 
import 'dart:js';

//Library Scoped methods and attributes
String typeof(var obj){
  return((obj is BigNumber)?'BigNumber':reflect(obj).type.reflectedType.toString());
  }//end Dart version of typeof

class BigNumber{
  //Static methods and attributes
  static Exception noBigNumberJS=new Exception('Big:BigNumber:: Your Dart project cannot access bignumber.js!,\n'+
      'Add the HTML tag <script src="bignumber.js"></script> to your <<project>>.html file!\n');
  static Exception noAccessToConfig=new Exception("Big::BigNumber.config(): Your version of bignumber.js has not been modified for the Dart Language!,\n"+
      "Add the code line P['config']=BigNumber['config']; after the config function in bignumber.js!\n"+
      "This will enable calls to BigNumber.config() from Dart.");
  static JsObject configObj=null;
  static Map config([Map<String, dynamic> arguments=null]){
    JsObject configCurrent=null;
    Map m=new Map();
    arguments=(arguments==null)?new Map():arguments;
    JsObject args = new JsObject(context['Object'],['0']);
    try{
      if(configObj==null)configObj=new JsObject(context['BigNumber'],['0']);
    }catch(ee){
      throw noBigNumberJS;//Then halt!
    }//end try
    try{
      arguments.forEach((param, value){
        if(param=='EXPONENTIAL_AT'||param=='RANGE'){
          if(value is! num){
            value=new JsObject(context['Array'],[(value[0] is num)?value[0].floor():value[0], (value[1] is num)?value[1].floor():value[1]]);
          }//end if
        }//end if
        args[param]=value;
      });//end foreach
      configCurrent=configObj.callMethod('config',[args]);
    }on NoSuchMethodError catch(ee){
      print(noAccessToConfig.toString());
      m['No_Access_To_Config!']=noAccessToConfig.toString();
      return (m);
    }catch(ee){
      print(ee.toString());
      m['Config Error!']=ee.toString();
      return (m);
    }//end try
    m['DECIMAL_PLACES']=configCurrent['DECIMAL_PLACES'];
    m['ROUNDING_MODE']=configCurrent['ROUNDING_MODE'];
    m['EXPONENTIAL_AT']=configCurrent['EXPONENTIAL_AT'];
    m['RANGE']=configCurrent['RANGE'];
    m['ERRORS']=configCurrent['ERRORS'];
    return (m);
  }//end config
  static String test(){
    String str='';
    print('Testing BigNumber ...............START..................');
    BigNumber bigTest=null;
    BigNumber bigTestFromBigNumber;
    Map m = config({'DECIMAL_PLACES' : 20});//test that call to config is enabled!
    str+='config() test:\n'+m.toString();
  try{
    bigTest = new BigNumber('12345678901234567890.12345678901234567890');
    str+=r"BigNumber bigTest = new BigNumber('12345678901234567890.12345678901234567890');";
    str+='\nabs(): '+bigTest.abs().toS();
    str+='\nceil(): '+bigTest.ceil().toS();
    str+='\ncmp(989897): '+bigTest.cmp(989897).toString();
    str+='\ndiv(self): '+bigTest.div(bigTest).toS();
    str+='\ndiv(54444): '+bigTest.div(54444).toS();
    str+='\nfloor(): '+bigTest.floor().toS();
    str+='\nminus(self): '+bigTest.minus(bigTest).toS();
    str+='\nneg(): '+bigTest.neg().toS();
    str+='\nplus(self): '+bigTest.plus(bigTest).toS();
    str+='\npow(2): '+bigTest.pow(2).toS();
    str+='\nround(): '+bigTest.round(4).toS();
    str+='\n(64*64).sqrt(): '+new BigNumber(64*64).sqrt().toS();
    str+='\ntimes(self): '+bigTest.times(bigTest).toS();
    str+='\ntoExponential(): '+bigTest.toExponential();
    str+='\ntoFixed(10): '+bigTest.toFixed(10);
    str+='\nequals(454.55)? ${bigTest.equals(454.55)}';
    str+='\ngreaterThan(454.55)? ${bigTest.greaterThan(454.55)}';
    str+='\ngreaterThanOrEqualTo(454.55)? ${bigTest.greaterThanOrEqualTo(454.55)}';
    str+='\nlessThan(454.55)? ${bigTest.lessThan(454.55)}';
    str+='\nlessThanOrEqualTo(454.55)? ${bigTest.lessThanOrEqualTo(454.55)}';
    List toFraction = bigTest.toFraction();
    str+='\ntoFraction(): ';
    toFraction.forEach((E){str+='\n\t'+E.toString();});
    str+='\ntoPrecision(60): '+bigTest.toPrecision(60);
    str+='\ntoString(base:16): '+bigTest.toString(16);
    bigTestFromBigNumber=new BigNumber(bigTest);
    str+='\nTest constructor: b=new BigNumber(BigNumber): '+bigTestFromBigNumber.toString();
  }catch(ee){
    str+='\n'+ee.toString();
  }finally{}
    print(str);
    print('Testing BigNumber ...............END....................');
    return(str);
  }//end test
  /********************************END TEST*****************************************************/
  //Instance methods and attributes
  String sourceType='unknown';
  JsObject JsObject_BigNumber = null;
  //Main Constructor
  BigNumber(var value, [int base=null]) {
    sourceType = typeof(value);
    try{JsObject_BigNumber=new JsObject(context['BigNumber'], [(value is BigNumber)?value.JsObject_BigNumber:value, base]);}catch(ee){throw noBigNumberJS;}
  }//end constructor
  // PROTOTYPE/INSTANCE METHODS
  BigNumber abs(){return absoluteValue();}
  BigNumber absoluteValue(){return(new BigNumber(JsObject_BigNumber.callMethod('absoluteValue')));}
  BigNumber ceil(){return(new BigNumber(JsObject_BigNumber.callMethod('ceil')));}
  int cmp(var y, [int base=null]){return(comparedTo(y, base));}
  int comparedTo(var y, [int base=null]) {return(JsObject_BigNumber.callMethod('comparedTo',[(y is BigNumber)?y.JsObject_BigNumber:y, base]));}
  BigNumber div(var y, [int base=null]){return(dividedBy(y, base));}
  BigNumber dividedBy(var y, [int base=null]){
    return(new BigNumber(JsObject_BigNumber.callMethod('dividedBy',[(y is BigNumber)?y.JsObject_BigNumber:y, base])));
  }//end method
  bool eq(var n, [int base=null]){return(equals(n, base));}
  bool equals(var n, [int base=null]){return(JsObject_BigNumber.callMethod('equals',[(n is BigNumber)?n.JsObject_BigNumber:n, base]));}
  bool gt(var n, [int base=null]){return(greaterThan(n, base));}
  bool greaterThan(var n, [int base=null]){return(JsObject_BigNumber.callMethod('greaterThan',[(n is BigNumber)?n.JsObject_BigNumber:n, base]));}
  bool gte(var n, [int base=null]){return(greaterThanOrEqualTo(n, base));}
  bool greaterThanOrEqualTo(
       var n, [int base=null]){return(JsObject_BigNumber.callMethod('greaterThanOrEqualTo',[(n is BigNumber)?n.JsObject_BigNumber:n, base]));}
  bool isF(){return(isFinite());}
  bool isFinite(){return(JsObject_BigNumber.callMethod('isFinite'));}
  bool isNaN(){return(JsObject_BigNumber.callMethod('isNaN'));}
  bool isNeg(){return(isNegative());} 
  bool isNegative(){return(JsObject_BigNumber.callMethod('isNegative'));}
  bool isZ(){return(isZero());}
  bool isZero(){return(JsObject_BigNumber.callMethod('isZero'));}
  bool lt(var n, [int base=null]){return(lessThan(n, base));}
  bool lessThan(var n, [int base=null]){return(JsObject_BigNumber.callMethod('lessThan',[(n is BigNumber)?n.JsObject_BigNumber:n, base]));}
  bool lte(var n, [int base=null]){return(lessThanOrEqualTo(n, base));}
  bool lessThanOrEqualTo(
       var n, [int base=null]) {return(JsObject_BigNumber.callMethod('lessThanOrEqualTo',[(n is BigNumber)?n.JsObject_BigNumber:n, base]));}
  BigNumber floor(){return(new BigNumber(JsObject_BigNumber.callMethod('floor')));}
  BigNumber minus(var y, [int base=null]) {return(new BigNumber(JsObject_BigNumber.callMethod('minus',[(y is BigNumber)?y.JsObject_BigNumber:y, base])));}
  BigNumber mod(var y, [int base=null]){return(modulo(y, base));}
  BigNumber modulo(var y, [int base=null]) {return(new BigNumber(JsObject_BigNumber.callMethod('modulo',[(y is BigNumber)?y.JsObject_BigNumber:y, base])));}
  BigNumber neg() {return(negated());}
  BigNumber negated(){return(new BigNumber(JsObject_BigNumber.callMethod('negated')));}
  BigNumber plus(var y, [int base=null]){return(new BigNumber(JsObject_BigNumber.callMethod('plus',[(y is BigNumber)?y.JsObject_BigNumber:y, base])));}
  BigNumber pow(int e){return(toPower(e));}
  BigNumber toPower(int e) {return(new BigNumber(JsObject_BigNumber.callMethod('toPower',[e])));}
  BigNumber round(decimalPlaces, [int roundingMode=null]){return(new BigNumber(JsObject_BigNumber.callMethod('round',[decimalPlaces,roundingMode])));}
  BigNumber sqrt(){return(squareRoot());}
  BigNumber squareRoot(){return(new BigNumber(JsObject_BigNumber.callMethod('squareRoot')));}
  BigNumber times(var y, [int base=null]){return(new BigNumber(JsObject_BigNumber.callMethod('times',[(y is BigNumber)?y.JsObject_BigNumber:y, base])));}
  String toE([int decimal_places=null]){return(toExponential(decimal_places));}
  String toExponential([int decimal_places=null]){return(JsObject_BigNumber.callMethod('toExponential',[decimal_places]));}
  String toF([int decimal_places=null] ){return(toFixed(decimal_places));}
  String toFixed([int decimal_places=null]){return(JsObject_BigNumber.callMethod('toFixed',[decimal_places]));}
  List toFr([var maxDenominator=null]){return(toFraction(maxDenominator));}
  List toFraction([var maxDenominator=null]){return(JsObject_BigNumber.callMethod('toFraction',[maxDenominator]));}
  String toP([int significant_figures=null]){return(toPrecision(significant_figures));}
  String toPrecision([int significant_figures=null]){return(JsObject_BigNumber.callMethod('toPrecision',[significant_figures]));}
  String toS([int base=null]){return(this.toString(base));}
  String toString([int base=null]){return(JsObject_BigNumber.callMethod('toString',[base]));}
  String valueOf(){return(JsObject_BigNumber.callMethod('toString'));}

  String toStringInstance(){//JsObject_BigNumber
    String str='';
    str+='BigNumber::toStringInstance: type: '+sourceType+', Sign: '+JsObject_BigNumber['s'].toString()+', Exponent: '
        +JsObject_BigNumber['e'].toString()+',\n component:[';
    JsObject_BigNumber['c'].forEach((E){str+=' '+E.toString();});
    str+=' ]';
    str+=',\n String: toString['+toString()+']';
    str+=',\n toFixed['+toF()+']';
    str+='\n abs['+abs().toS()+']';
    return(str);
  }//end method
}//end class
